==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/TrafficWeightArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Traffic weight assigned to a revision
 * @property label Associates a traffic label with a revision
 * @property latestRevision Indicates that the traffic weight belongs to a latest stable revision
 * @property revisionName Name of a revision
 * @property weight Traffic weight assigned to a revision
 */
public data class TrafficWeightArgs(
    public val label: Output<String>? = null,
    public val latestRevision: Output<Boolean>? = null,
    public val revisionName: Output<String>? = null,
    public val weight: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.TrafficWeightArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.TrafficWeightArgs =
        com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder()
            .label(label?.applyValue({ args0 -> args0 }))
            .latestRevision(latestRevision?.applyValue({ args0 -> args0 }))
            .revisionName(revisionName?.applyValue({ args0 -> args0 }))
            .weight(weight?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TrafficWeightArgs].
 */
@PulumiTagMarker
public class TrafficWeightArgsBuilder internal constructor() {
    private var label: Output<String>? = null

    private var latestRevision: Output<Boolean>? = null

    private var revisionName: Output<String>? = null

    private var weight: Output<Int>? = null

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("emtwnculelsmpuaw")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("rktwdutubioctyfk")
    public suspend fun latestRevision(`value`: Output<Boolean>) {
        this.latestRevision = value
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("iojvyvlxmsxjmaoy")
    public suspend fun revisionName(`value`: Output<String>) {
        this.revisionName = value
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("sbauoyfijvtdbmib")
    public suspend fun weight(`value`: Output<Int>) {
        this.weight = value
    }

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("daygthpsthxcknwu")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("adojhunnsoijaobg")
    public suspend fun latestRevision(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.latestRevision = mapped
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("barujvepurrnyqst")
    public suspend fun revisionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.revisionName = mapped
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("tjhfmbkbynwhtuhk")
    public suspend fun weight(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weight = mapped
    }

    internal fun build(): TrafficWeightArgs = TrafficWeightArgs(
        label = label,
        latestRevision = latestRevision,
        revisionName = revisionName,
        weight = weight,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/TrafficWeightArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Traffic weight assigned to a revision
 * @property label Associates a traffic label with a revision
 * @property latestRevision Indicates that the traffic weight belongs to a latest stable revision
 * @property revisionName Name of a revision
 * @property weight Traffic weight assigned to a revision
 */
public data class TrafficWeightArgs(
    public val label: Output<String>? = null,
    public val latestRevision: Output<Boolean>? = null,
    public val revisionName: Output<String>? = null,
    public val weight: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.TrafficWeightArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.TrafficWeightArgs =
        com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder()
            .label(label?.applyValue({ args0 -> args0 }))
            .latestRevision(latestRevision?.applyValue({ args0 -> args0 }))
            .revisionName(revisionName?.applyValue({ args0 -> args0 }))
            .weight(weight?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TrafficWeightArgs].
 */
@PulumiTagMarker
public class TrafficWeightArgsBuilder internal constructor() {
    private var label: Output<String>? = null

    private var latestRevision: Output<Boolean>? = null

    private var revisionName: Output<String>? = null

    private var weight: Output<Int>? = null

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("jyykfjrberqigjlo")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("pginiynuonsbeawi")
    public suspend fun latestRevision(`value`: Output<Boolean>) {
        this.latestRevision = value
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("jdylfwenkjpyseai")
    public suspend fun revisionName(`value`: Output<String>) {
        this.revisionName = value
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("wibrbgaakpvcaiyb")
    public suspend fun weight(`value`: Output<Int>) {
        this.weight = value
    }

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("xjtueeofskuvrjco")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("obgebisqvqnnjeew")
    public suspend fun latestRevision(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.latestRevision = mapped
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("ygjwfdydiomxvbav")
    public suspend fun revisionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.revisionName = mapped
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("suteabmnpbicqkxi")
    public suspend fun weight(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weight = mapped
    }

    internal fun build(): TrafficWeightArgs = TrafficWeightArgs(
        label = label,
        latestRevision = latestRevision,
        revisionName = revisionName,
        weight = weight,
    )
}
